<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.thedotstore.com/
 * @since             1.0.0
 * @package           Woocommerce_Blocker_Prevent_Fake_Orders_And_Blacklist_Fraud_Customers
 *
 * @wordpress-plugin
 * Plugin Name: Fraud Prevention For Woocommerce
 * Plugin URI:        https://www.thedotstore.com/
 * Description:       Prevent fake orders and Blacklist fraud customers allows your WooCommerce store to refuse orders from specific user, based on blacklist rules.
 * Version:           2.1.3
 * Author:            theDotstore
 * Author URI:        https://www.thedotstore.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       woo-blocker-lite-prevent-fake-orders-and-blacklist-fraud-customers
 * Domain Path:       /languages
 * WC tested up to: 7.1.0
 */
// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
    die;
}

if ( function_exists( 'wbpfoabfc_fs' ) ) {
    wbpfoabfc_fs()->set_basename( false, __FILE__ );
    return;
}


if ( !function_exists( 'wbpfoabfc_fs' ) ) {
    // Create a helper function for easy SDK access.
    function wbpfoabfc_fs()
    {
        global  $wbpfoabfc_fs ;
        
        if ( !isset( $wbpfoabfc_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            $wbpfoabfc_fs = fs_dynamic_init( array(
                'id'               => '3493',
                'slug'             => 'woocommerce-blocker',
                'type'             => 'plugin',
                'public_key'       => 'pk_00eede06ec781d063c23f65779beb',
                'is_premium'       => false,
                'has_addons'       => false,
                'has_paid_plans'   => true,
                'is_org_compliant' => false,
                'trial'            => array(
                'days'               => 14,
                'is_require_payment' => true,
            ),
                'menu'             => array(
                'slug'       => 'woocommerce_blacklist_users',
                'first-path' => 'admin.php?page=woocommerce_blacklist_users',
                'contact'    => false,
                'support'    => false,
            ),
                'is_live'          => true,
            ) );
        }
        
        return $wbpfoabfc_fs;
    }
    
    // Init Freemius.
    wbpfoabfc_fs();
    // Signal that SDK was initiated.
    do_action( 'wbpfoabfc_fs_loaded' );
    wbpfoabfc_fs()->get_upgrade_url();
}

if ( !defined( 'WB_PLUGIN_URL' ) ) {
    define( 'WB_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
}
if ( !defined( 'WB_PLUGIN_VERSION' ) ) {
    define( 'WB_PLUGIN_VERSION', '2.1.3' );
}
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-woocommerce-blocker-prevent-fake-orders-and-blacklist-fraud-customers-activator.php
 */
function activate_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers()
{
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-blocker-prevent-fake-orders-and-blacklist-fraud-customers-activator.php';
    Woocommerce_Blocker_Prevent_Fake_Orders_And_Blacklist_Fraud_Customers_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-woocommerce-blocker-prevent-fake-orders-and-blacklist-fraud-customers-deactivator.php
 */
function deactivate_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers()
{
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-blocker-prevent-fake-orders-and-blacklist-fraud-customers-deactivator.php';
    Woocommerce_Blocker_Prevent_Fake_Orders_And_Blacklist_Fraud_Customers_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers' );
register_deactivation_hook( __FILE__, 'deactivate_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers' );
/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-blocker-prevent-fake-orders-and-blacklist-fraud-customers.php';
require plugin_dir_path( __FILE__ ) . 'includes/excelwriter.inc.php';
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers()
{
    $plugin = new Woocommerce_Blocker_Prevent_Fake_Orders_And_Blacklist_Fraud_Customers();
    $plugin->run();
}

add_action( 'plugins_loaded', 'wcblu_plugin_init' );
function wcblu_plugin_init()
{
    $wc_active = in_array( 'woocommerce/woocommerce.php', get_option( 'active_plugins' ), true );
    
    if ( current_user_can( 'activate_plugins' ) && false === $wc_active ) {
        add_action( 'admin_notices', 'wcblu_plugin_admin_notice' );
        add_action( 'admin_init', 'wcblu_deactivate_plugin' );
        //Deactivate the plugin as it should not be activated.
    } else {
        run_woocommerce_blocker_prevent_fake_orders_and_blacklist_fraud_customers();
    }

}

/**
 * Show admin notice in case of WooCommerce plguin is missing
 */
function wcblu_plugin_admin_notice()
{
    $wcblu_plugin = 'Fraud Prevention For Woocommerce';
    $wc_plugin = 'WooCommerce';
    ?>
    <div class="error">
        <p>
			<?php 
    echo  sprintf( esc_html__( '%1$s requires %2$s to be installed & activated!', 'woo-blocker-lite-prevent-fake-orders-and-blacklist-fraud-customers' ), '<strong>' . esc_html( $wcblu_plugin ) . '</strong>', '<a href="' . esc_url( 'https://wordpress.org/plugins/woocommerce/' ) . '" target="_blank"><strong>' . esc_html( $wc_plugin ) . '</strong></a>' ) ;
    ?>
        </p>
    </div><?php 
}

/**
 * Deactivate the plugin.
 */
function wcblu_deactivate_plugin()
{
    deactivate_plugins( plugin_basename( __FILE__ ) );
    $activate_plugin_unset = filter_input( INPUT_GET, 'activate', FILTER_SANITIZE_STRING );
    unset( $activate_plugin_unset );
}
